@@ -15,3 +15,7 @@ test_that("list_cost_category_definitions", {
 test_that("list_cost_category_definitions", {
   expect_error(svc$list_cost_category_definitions(MaxResults = 20), NA)
 })
+
+test_that("list_savings_plans_purchase_recommendation_generation", {
+  expect_error(svc$list_savings_plans_purchase_recommendation_generation(), NA)
+})
